package App::plstrace;

our $DATE = '2014-12-10'; # DATE
our $VERSION = '0.06'; # VERSION

1;
# ABSTRACT: Trace Perl function calls

__END__

=pod

=encoding UTF-8

=head1 NAME

App::plstrace - Trace Perl function calls

=head1 VERSION

This document describes version 0.06 of App::plstrace (from Perl distribution App-plstrace), released on 2014-12-10.

=head1 SYNOPSIS

Please see L<plstrace> script.

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/App-plstrace>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-App-plstrace>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-plstrace>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2014 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
